% This script is part of the MUBI Scanner, developed by the
% Ultrasound Systems and Technology Group of the Spanish National 
% Research Council (USTG-ITEFI) and Grupo de Fsica Nuclear, of the
% University Complutense of Madrid (GFN-UCM), Spain.
%
% Contact information: mailynpl@gmail.com 
%
% This MATLAB script extracts information from the .mat files
% the acquisition system yields: 
% -Coordinates of the emitters and receivers (ASCII output file 'coordinates.txt')
% -Time series for the transmission modality (binary output file 'time_series.raw').
% For a complete description of the data stored in the .mat files see the
% LoadExample.m script and the website information.

clear all; close all;

% acquisition information
number_of_fanbeams    = 23;
emitters_per_array    = 16;
receivers_per_array   = 16;
arrayLocs_per_fanbeam = 11;
max_signals_length    = 3000; 
time_window_length    = 600;
temporal_sampling     = 0.05; % (micro seconds)
file_p = sprintf('parametros.mat');
load(file_p);

% save output files
fid1 = fopen('coordinates.txt','w');
fid2 = fopen('time_series.raw','wb');

for fb=1:number_of_fanbeams
    file = sprintf('Fan-Beam%02d.mat',fb);
    load(file);
    
    % saving signals      
     for jj = 1:emitters_per_array                                          % source element
        for kk = 1:arrayLocs_per_fanbeam                                    % position of the receiving array
            for ii = 1: receivers_per_array                                 % receiving element of the array
                
                recorded_signal = squeeze(Ascans_rx(kk,jj,ii,:));           % recorded signal (600 elements)
                base_line = mean(recorded_signal(1:50));                    % to eliminate base line, comment to avoid this step
                recorded_signal = recorded_signal - base_line;
                delay = round(tdlr_sitau(kk,jj,ii)/temporal_sampling);      % time delay in temporal bins (delay_microSecs/temporalSampling)
                signal = double([zeros(1,delay), recorded_signal', zeros(1,max_signals_length-time_window_length-delay)]); 
                
                x1 = coordenadas(kk,jj,ii,1,1);                             % all emitters x coordinate in (cm)
                y1 = coordenadas(kk,jj,ii,1,2);                             % all emitters y coordinate
                x2 = coordenadas(kk,jj,ii,2,1);                             % all receivers x coordinate
                y2 = coordenadas(kk,jj,ii,2,2);                             % all receivers y coordinate 
                                
                %plot(x1,y1,'o'); hold on;plot(x2,y2,'o');drawnow;
                %plot(signal);%hold on;drawnow;
                fprintf(fid1,'%10.4f %10.4f %10.4f %10.4f \n',x1,y1,x2,y2);
                fwrite(fid2,signal,'float');
            end
         end
     end         
end 

fclose(fid1);
fclose(fid2);